@@ -26,7 +26,8 @@ function helper.luacov_config(prefix)
       modules = {
          luacheck = "src/luacheck/init.lua",
          ["luacheck.*"] = "src",
-         ["luacheck.*.*"] = "src"
+         ["luacheck.*.*"] = "src",
+         ["luacheck.*.*.*"] = "src"
       },
       exclude = {
          "bin/luacheck$"
