@@ -9,6 +9,15 @@ local function trailing_whitespace_in_comment()
    return "Still bad"
 end
 
+local function trailing_whitespace_in_long_strings()
+   return [[
+      It gets worse   
+      Much worse
+   ]]
+   --[[ Same in long comments 
+   ]]
+end
+
 local function trailing_whitespace_mixed()
    return "Not much better" -- You bet! 
 end
@@ -28,6 +37,7 @@ end
 return { -- fake "module" table
    trailing_whitespace_in_code,
    trailing_whitespace_in_comment,
+   trailing_whitespace_in_long_strings,
    trailing_whitespace_mixed,
    whitespace_only_lines,
    inconsistent_indentation,
